==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/entity/TjBdcqzm.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author hqz
 * @version 1.0, 2017/4/10
 * @description 不动产证明表
 */
@Table(name = "tj_bdcqzm")
public class TjBdcqzm implements Serializable {
    @Id
    //证书编码
    private String zsid;
    //不动产单元号
    private String bdcdyh;
    //不动产权证号
    private String bdcqzh;
    //坐落
    private String zl;
    //权利人名称
    private String qlrmc;
    //权利人证件号
    private String qlrzjh;
    //义务人名称
    private String ywrmc;
    //义务人证件号
    private String ywrzjh;
    //限制状态
    private String qszt;
    //用途
    private String yt;
    //业务类型
    private String ywlx;
    //一级行政区代码
    private String yjxzq;
    //二级行政区代码
    private String ejxzq;

    public String getZsid() {
        return zsid;
    }

    public void setZsid(String zsid) {
        this.zsid = zsid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getYwrmc() {
        return ywrmc;
    }

    public void setYwrmc(String ywrmc) {
        this.ywrmc = ywrmc;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYwlx() {
        return ywlx;
    }

    public void setYwlx(String ywlx) {
        this.ywlx = ywlx;
    }

    public String getYjxzq() {
        return yjxzq;
    }

    public void setYjxzq(String yjxzq) {
        this.yjxzq = yjxzq;
    }

    public String getEjxzq() {
        return ejxzq;
    }

    public void setEjxzq(String ejxzq) {
        this.ejxzq = ejxzq;
    }
}

==> realestate-supervise-common-1.1.0-20251204.005843-70-sources.jar: cn/gtmap/realestate/supervise/entity/TjBdcqzm.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author hqz
 * @version 1.0, 2017/4/10
 * @description 不动产证明表
 */
@Table(name = "tj_bdcqzm")
public class TjBdcqzm implements Serializable {
    @Id
    //证书编码
    private String zsid;
    //不动产单元号
    private String bdcdyh;
    //不动产权证号
    private String bdcqzh;
    //坐落
    private String zl;
    //权利人名称
    private String qlrmc;
    //权利人证件号
    private String qlrzjh;
    //义务人名称
    private String ywrmc;
    //义务人证件号
    private String ywrzjh;
    //限制状态
    private String qszt;
    //用途
    private String yt;
    //业务类型
    private String ywlx;
    //一级行政区代码
    private String yjxzq;
    //二级行政区代码
    private String ejxzq;

    //业务号
    private  String ywh;

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getZsid() {
        return zsid;
    }

    public void setZsid(String zsid) {
        this.zsid = zsid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getYwrmc() {
        return ywrmc;
    }

    public void setYwrmc(String ywrmc) {
        this.ywrmc = ywrmc;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYwlx() {
        return ywlx;
    }

    public void setYwlx(String ywlx) {
        this.ywlx = ywlx;
    }

    public String getYjxzq() {
        return yjxzq;
    }

    public void setYjxzq(String yjxzq) {
        this.yjxzq = yjxzq;
    }

    public String getEjxzq() {
        return ejxzq;
    }

    public void setEjxzq(String ejxzq) {
        this.ejxzq = ejxzq;
    }
}
